@@ -21,8 +21,6 @@ import datetime
 import operator
 from concurrent.futures import ThreadPoolExecutor as Executor
 
-from gi.repository import GObject
-
 from kb4it.core.env import LPATH, GPATH, APP, ADOCPROPS, MAX_WORKERS, EOHMARK
 from kb4it.core.service import Service
 from kb4it.core.util import get_human_datetime
@@ -482,13 +480,21 @@ class KB4ITApp(Service):
         ## Keys/Values
         for kvpath in KV_PATH:
             key, value, COMPILE_VALUE = kvpath
-            docs = self.kbdict_new['metadata'][key][value]
+            docs = self.get_kbdict_value(key, value, new=True)
             sorted_docs = self.srvdtb.sort_by_date(docs)
             basename = "%s_%s" % (valid_filename(key), valid_filename(value))
+            pagination = {}
+            pagination['basename'] = basename
+            pagination['doclist'] = sorted_docs
+            pagination['title'] = None
+            pagination['function'] = 'build_cardset'
+            pagination['template'] = 'PAGE_PAGINATION_HEAD'
             if COMPILE_VALUE:
-                self.srvthm.build_pagination(basename, sorted_docs)
+                pagination['fake'] = False
+                self.srvthm.build_pagination(pagination)
             else:
-                pagelist = self.srvthm.build_pagination(basename, sorted_docs, fake=True)
+                pagination['fake'] = True
+                pagelist = self.srvthm.build_pagination(pagination)
                 for page in pagelist:
                     docname = "%s.html" % page
                     filename = os.path.join(self.runtime['dir']['cache'], docname)
@@ -630,6 +636,36 @@ class KB4ITApp(Service):
         shutil.rmtree(self.runtime['dir']['tmp'])
         self.log.debug("Temporary directory %s deleted successfully", self.runtime['dir']['tmp'])
 
+    def reset(self):
+        """
+        WARNING!!!
+        Reset environment given source and target directories.
+        Delete:
+        - Source directory
+        - Target directory
+        - Temporary directory
+        - Cache directory
+        - KB4IT database file for this environment
+        WARNING!!!
+
+        Please, note: if you pass the wrong directory...
+        """
+        KB4IT_DB_FILE = os.path.join(LPATH['DB'], 'kbdict-%s.json' % valid_filename(self.runtime['dir']['source']))
+        delete_target_contents(self.runtime['dir']['cache'])
+        self.kbdict_new = {}
+        self.kbdict_cur = {}
+        self.log.info("DIR[%s] deleted", self.runtime['dir']['cache'])
+        delete_target_contents(self.runtime['dir']['tmp'])
+        self.log.info("DIR[%s] deleted", self.runtime['dir']['tmp'])
+        delete_target_contents(self.runtime['dir']['source'])
+        self.log.info("DIR[%s] deleted", self.runtime['dir']['source'])
+        delete_target_contents(self.runtime['dir']['target'])
+        self.log.info("DIR[%s] deleted", self.runtime['dir']['target'])
+        delete_target_contents(KB4IT_DB_FILE)
+        self.log.info("FILE[%s] deleted", KB4IT_DB_FILE)
+        self.log.info("KB4IT environment reset")
+
+
     def run(self):
         """Start script execution following this flow.
 
